@@ -53,7 +53,7 @@ def potential_temperature(pressure, temperature):
     --------
     >>> from metpy.units import units
     >>> metpy.calc.potential_temperature(800. * units.mbar, 273. * units.kelvin)
-    290.9814150577374
+    <Quantity(290.96653180346203, 'kelvin')>
     """
     return temperature * (P0 / pressure).to('dimensionless')**kappa
 
@@ -219,7 +219,7 @@ def lfc(pressure, temperature, dewpt):
     Returns
     -------
     `pint.Quantity`
-        The LFC
+        The LFC pressure and temperature
 
     See Also
     --------
@@ -232,7 +232,7 @@ def lfc(pressure, temperature, dewpt):
     x, y = find_intersections(pressure[1:], ideal_profile[1:], temperature[1:],
                               direction='increasing')
     if len(x) == 0:
-        return None, None
+        return np.nan * pressure.units, np.nan * temperature.units
     else:
         return x[0], y[0]
 
@@ -269,7 +269,7 @@ def el(pressure, temperature, dewpt):
 
     # If there is only one intersection, it's the LFC and we return None.
     if len(x) <= 1:
-        return None, None
+        return np.nan * pressure.units, np.nan * temperature.units
     else:
         return x[-1], y[-1]
 
