@@ -49,8 +49,8 @@ def check_and_drop_units(actual, desired):
             if hasattr(actual, 'units'):
                 actual = actual.to('dimensionless')
     except DimensionalityError:
-        raise AssertionError('Units are not compatible: {} should be {}'.format(actual.units,
-                                                                                desired.units))
+        raise AssertionError('Units are not compatible: {} should be {}'.format(
+            actual.units, getattr(desired, 'units', 'dimensionless')))
     except AttributeError:
         pass
 
@@ -62,6 +62,15 @@ def check_and_drop_units(actual, desired):
     return actual, desired
 
 
+def assert_nan(value, units):
+    """Helper to check for nan with proper units."""
+    if not np.isnan(value):
+        pytest.fail('{} is not np.nan'.format(value))
+
+    check_and_drop_units(value, np.nan * units)
+    return True
+
+
 def assert_almost_equal(actual, desired, decimal=7):
     """Check that values are almost equal, including units.
 
